diff --git a/htdocs/core/modules/expedition/doc/pdf_espadon.modules.php b/htdocs/core/modules/expedition/doc/pdf_espadon.modules.php
index fa47f7be159..a038705ea22 100644
--- a/htdocs/core/modules/expedition/doc/pdf_espadon.modules.php
+++ b/htdocs/core/modules/expedition/doc/pdf_espadon.modules.php
@@ -642,7 +642,7 @@ class pdf_espadon extends ModelePdfExpedition
if ($this->getColumnStatus('weight')) {
- $this->printStdColumnContent($pdf, $curY, 'weight', $weighttxt.(($weighttxt && $voltxt) ? '
' : '').$voltxt, array('html'=>1));
+ $this->printStdColumnContent($pdf, $curY, 'weight', $weighttxt.(($weighttxt && $voltxt) ? '
' : '').$voltxt);
$nexY = max($pdf->GetY(), $nexY);
}
diff --git a/htdocs/core/modules/expedition/doc/pdf_merou.modules.php b/htdocs/core/modules/expedition/doc/pdf_merou.modules.php
index 87098733502..69105dd31cc 100644
--- a/htdocs/core/modules/expedition/doc/pdf_merou.modules.php
+++ b/htdocs/core/modules/expedition/doc/pdf_merou.modules.php
@@ -584,7 +584,7 @@ class pdf_merou extends ModelePdfExpedition
$origin_id = $object->origin_id;
// Add list of linked elements
- $posy = pdf_writeLinkedObjects($pdf, $object, $outputlangs, $posx, $posy, 100, 3, 'R', $default_font_size - 1, $hookmanager);
+ $posy = pdf_writeLinkedObjects($pdf, $object, $outputlangs, $posx, $posy, 100, 3, 'R', $default_font_size - 1);
//$this->Code39($Xoff+43, $Yoff+1, $object->commande->ref,$ext = true, $cks = false, $w = 0.4, $h = 4, $wide = true);
//Definition Location of the Company block
diff --git a/htdocs/core/modules/facture/doc/pdf_crabe.modules.php b/htdocs/core/modules/facture/doc/pdf_crabe.modules.php
index 8046347e881..091b78d2ed5 100644
--- a/htdocs/core/modules/facture/doc/pdf_crabe.modules.php
+++ b/htdocs/core/modules/facture/doc/pdf_crabe.modules.php
@@ -874,12 +874,12 @@ class pdf_crabe extends ModelePDFFactures
/**
* Show payments table
*
- * @param TCPDF $pdf Object PDF
- * @param Facture $object Object invoice
- * @param int $posy Position y in PDF
- * @param Translate $outputlangs Object langs for output
- * @param int $heightforfooter height for footer
- * @return int <0 if KO, >0 if OK
+ * @param TCPDF $pdf Object PDF
+ * @param Facture $object Object invoice
+ * @param int $posy Position y in PDF
+ * @param Translate $outputlangs Object langs for output
+ * @param int $heightforfooter Height for footer
+ * @return int <0 if KO, >0 if OK
*/
protected function _tableau_versements(&$pdf, $object, $posy, $outputlangs, $heightforfooter = 0)
{
diff --git a/htdocs/core/modules/propale/doc/pdf_azur.modules.php b/htdocs/core/modules/propale/doc/pdf_azur.modules.php
index c6bb975092d..abf2b843a39 100644
--- a/htdocs/core/modules/propale/doc/pdf_azur.modules.php
+++ b/htdocs/core/modules/propale/doc/pdf_azur.modules.php
@@ -1458,9 +1458,10 @@ class pdf_azur extends ModelePDFPropales
* @param Propal $object Object to show
* @param int $showaddress 0=no, 1=yes
* @param Translate $outputlangs Object lang for output
+ * @param Translate $outputlangsbis Object lang for output bis
* @return void
*/
- protected function _pagehead(&$pdf, $object, $showaddress, $outputlangs)
+ protected function _pagehead(&$pdf, $object, $showaddress, $outputlangs, $outputlangsbis = null)
{
global $conf, $langs;
diff --git a/htdocs/core/triggers/interface_50_modTicket_TicketEmail.class.php b/htdocs/core/triggers/interface_50_modTicket_TicketEmail.class.php
index e13328e0a2a..840d6d9c3ba 100644
--- a/htdocs/core/triggers/interface_50_modTicket_TicketEmail.class.php
+++ b/htdocs/core/triggers/interface_50_modTicket_TicketEmail.class.php
@@ -169,7 +169,7 @@ class InterfaceTicketEmail extends DolibarrTriggers
}
if ($sendto) {
- $this->composeAndSendCustomerMessage($sendto, $subject_customer, $body_customer, $see_ticket_customer, $object, $langs, $conf);
+ $this->composeAndSendCustomerMessage($sendto, $subject_customer, $body_customer, $see_ticket_customer, $object, $langs);
}
}
diff --git a/htdocs/install/step5.php b/htdocs/install/step5.php
index 89681794aeb..ee592007522 100644
--- a/htdocs/install/step5.php
+++ b/htdocs/install/step5.php
@@ -228,7 +228,7 @@ if ($action == "set" || empty($action) || preg_match('/upgrade/i', $action)) {
$success = 1;
} else {
dolibarr_install_syslog('step5: FailedToCreateAdminLogin '.$newuser->error, LOG_ERR);
- setEventMessage($langs->trans("FailedToCreateAdminLogin").' '.$newuser->error, null, 'errors');
+ setEventMessages($langs->trans("FailedToCreateAdminLogin").' '.$newuser->error, null, 'errors');
//header("Location: step4.php?error=3&selectlang=$setuplang".(isset($login) ? '&login='.$login : ''));
print '
diff --git a/htdocs/core/modules/supplier_invoice/doc/pdf_canelle.modules.php b/htdocs/core/modules/supplier_invoice/doc/pdf_canelle.modules.php
index 23a38b961ec..b026a39791c 100644
--- a/htdocs/core/modules/supplier_invoice/doc/pdf_canelle.modules.php
+++ b/htdocs/core/modules/supplier_invoice/doc/pdf_canelle.modules.php
@@ -967,13 +967,14 @@ class pdf_canelle extends ModelePDFSuppliersInvoices
/**
* Show payments table
*
* @param TCPDF $pdf Object PDF
* @param Object $object Object to show
* @param int $posy Position y in PDF
* @param Translate $outputlangs Object langs for output
* @return int <0 if KO, >0 if OK
*/
- protected function _tableau_versements(&$pdf, $object, $posy, $outputlangs)
+ protected function _tableau_versements(&$pdf, $object, $posy, $outputlangs, $heightforfooter = 0)
{
// phpcs:enable
global $conf;
@@ -967,13 +967,14 @@ class pdf_canelle extends ModelePDFSuppliersInvoices
* Show payments table
*
- * @param TCPDF $pdf Object PDF
- * @param Object $object Object to show
- * @param int $posy Position y in PDF
- * @param Translate $outputlangs Object langs for output
- * @return int <0 if KO, >0 if OK
+ * @param TCPDF $pdf Object PDF
+ * @param Object $object Object to show
+ * @param int $posy Position y in PDF
+ * @param Translate $outputlangs Object langs for output
+ * @param int $heightforfooter Height for footer
+ * @return int <0 if KO, >0 if OK
*/